@@ -41,9 +41,17 @@ from cloudify_rest_client.summary import SummariesClient
 from cloudify_rest_client.snapshots import SnapshotsClient
 from cloudify_rest_client.cluster import ClusterStatusClient
 from cloudify_rest_client.blueprints import BlueprintsClient
-from cloudify_rest_client.executions import ExecutionsClient
+from cloudify_rest_client.executions import (
+    ExecutionsClient,
+    ExecutionGroupsClient
+)
+from cloudify_rest_client.execution_schedules import ExecutionSchedulesClient
 from cloudify_rest_client.user_groups import UserGroupsClient
-from cloudify_rest_client.deployments import DeploymentsClient
+from cloudify_rest_client.deployments import (
+    DeploymentsClient,
+    DeploymentGroupsClient
+)
+from cloudify_rest_client.permissions import PermissionsClient
 from cloudify_rest_client.maintenance import MaintenanceModeClient
 from cloudify_rest_client.plugins_update import PluginsUpdateClient
 from cloudify_rest_client.node_instances import NodeInstancesClient
@@ -55,6 +63,7 @@ from cloudify_rest_client.deployment_modifications import (
 from cloudify_rest_client.inter_deployment_dependencies import (
     InterDeploymentDependencyClient)
 from cloudify_rest_client.labels import DeploymentsLabelsClient
+from cloudify_rest_client.filters import FiltersClient
 
 try:
     from requests_kerberos import HTTPKerberosAuth
@@ -444,9 +453,13 @@ class CloudifyClient(object):
                                          trust_all, username, password,
                                          token, tenant, kerberos_env, timeout)
         self.blueprints = BlueprintsClient(self._client)
+        self.permissions = PermissionsClient(self._client)
         self.snapshots = SnapshotsClient(self._client)
         self.deployments = DeploymentsClient(self._client)
+        self.deployment_groups = DeploymentGroupsClient(self._client)
         self.executions = ExecutionsClient(self._client)
+        self.execution_groups = ExecutionGroupsClient(self._client)
+        self.execution_schedules = ExecutionSchedulesClient(self._client)
         self.nodes = NodesClient(self._client)
         self.node_instances = NodeInstancesClient(self._client)
         self.manager = ManagerClient(self._client)
@@ -475,3 +488,4 @@ class CloudifyClient(object):
         self.inter_deployment_dependencies = InterDeploymentDependencyClient(
             self._client)
         self.deployments_labels = DeploymentsLabelsClient(self._client)
+        self.filters = FiltersClient(self._client)
